@@ -5,36 +5,28 @@
 **
 ** This file is part of the QtSensor module of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
+** $QT_BEGIN_LICENSE:LGPL21$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
+** a written agreement between you and Digia. For licensing terms and
+** conditions see http://qt.digia.com/licensing. For further information
 ** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file. Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
+** rights. These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
-**
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -153,6 +145,25 @@ public class QtSensors implements SensorEventListener
         return angles;
     }
 
+    private static float[] mRotation = new float[9];
+    private static float[] mOrientation = new float[3];
+    private static float[] mAcc = new float[3];
+    private static float[] mMag = new float[3];
+
+    private static float getCompassAzimuth(float a0, float a1, float a2, float m0, float m1, float m2)
+    {
+        mAcc[0] = a0;
+        mAcc[1] = a1;
+        mAcc[2] = a2;
+        mMag[0] = m0;
+        mMag[1] = m1;
+        mMag[2] = m2;
+
+        SensorManager.getRotationMatrix(mRotation, null, mAcc, mMag);
+        SensorManager.getOrientation(mRotation, mOrientation);
+        return mOrientation[0];
+    }
+
     public static native void accuracyChanged(int sensorType, int accuracy);
     public static native void sensorChanged(int sensorType, long timestamp, float[] values);
 
