@@ -5,36 +5,28 @@
 **
 ** This file is part of the QtSensors module of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
+** $QT_BEGIN_LICENSE:LGPL21$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
+** a written agreement between you and Digia. For licensing terms and
+** conditions see http://qt.digia.com/licensing. For further information
 ** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file. Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
+** rights. These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
-**
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -54,6 +46,7 @@ static jmethodID registerSensorMethodId;
 static jmethodID unregisterSensorMethodId;
 static jmethodID getSensorDescriptionMethodId;
 static jmethodID getSensorMaximumRangeMethodId;
+static jmethodID getCompassAzimuthId;
 
 static QHash<int, QList<AndroidSensors::AndroidSensorsListenerInterface *> > listenersHash;
 QReadWriteLock listenersLocker;
@@ -166,6 +159,20 @@ namespace AndroidSensors
         }
         return true;
     }
+
+    qreal getCompassAzimuth(jfloat *accelerometerReading, jfloat *magnetometerReading)
+    {
+            AttachedJNIEnv aenv;
+            if (!aenv.jniEnv)
+                return 0.0;
+            return aenv.jniEnv->CallStaticFloatMethod(sensorsClass, getCompassAzimuthId,
+                                                        accelerometerReading[0],
+                                                        accelerometerReading[1],
+                                                        accelerometerReading[2],
+                                                        magnetometerReading[0],
+                                                        magnetometerReading[1],
+                                                        magnetometerReading[2]);
+    }
 }
 
 static const char logTag[] = "Qt";
@@ -227,6 +234,7 @@ static bool registerNatives(JNIEnv *env)
     GET_AND_CHECK_STATIC_METHOD(unregisterSensorMethodId, sensorsClass, "unregisterSensor", "(I)Z");
     GET_AND_CHECK_STATIC_METHOD(getSensorDescriptionMethodId, sensorsClass, "getSensorDescription", "(I)Ljava/lang/String;");
     GET_AND_CHECK_STATIC_METHOD(getSensorMaximumRangeMethodId, sensorsClass, "getSensorMaximumRange", "(I)F");
+    GET_AND_CHECK_STATIC_METHOD(getCompassAzimuthId, sensorsClass, "getCompassAzimuth", "(FFFFFF)F");
 
     return true;
 }
