@@ -1,40 +1,32 @@
 /****************************************************************************
 **
-** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
 ** Contact: http://www.qt-project.org/legal
 **
 ** This file is part of the QtSensors module of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
+** $QT_BEGIN_LICENSE:LGPL21$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
+** a written agreement between you and Digia. For licensing terms and
+** conditions see http://qt.digia.com/licensing. For further information
 ** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file. Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
+** rights. These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
-**
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -48,12 +40,15 @@
 #include "sensorlog_p.h"
 #include <QTimer>
 #include <QFile>
+#include <QLoggingCategory>
 
 QT_BEGIN_NAMESPACE
 
 typedef QHash<QByteArray,QSensorBackendFactory*> FactoryForIdentifierMap;
 typedef QHash<QByteArray,FactoryForIdentifierMap> BackendIdentifiersForTypeMap;
 
+static QLoggingCategory sensorsCategory("qt.sensors");
+
 class QSensorManagerPrivate : public QObject
 {
     friend class QSensorManager;
@@ -77,7 +72,6 @@ public:
             loadExternalPlugins = false;
         }
     }
-
     bool loadExternalPlugins;
     PluginLoadingState pluginLoadingState;
     QFactoryLoader *loader;
@@ -101,9 +95,16 @@ public:
         if (config.isEmpty()) return; // QStandardPaths is broken?
         config += QLatin1String("/QtProject/Sensors.conf");
 #endif
-        if (!QFile::exists(config)) return;
+        qCDebug(sensorsCategory) << "Loading config from" << config;
+        if (!QFile::exists(config)) {
+            qCDebug(sensorsCategory) << "There is no config file" << config;
+            return;
+        }
         QFile cfgfile(config);
-        if (!cfgfile.open(QFile::ReadOnly)) return;
+        if (!cfgfile.open(QFile::ReadOnly)) {
+            qCWarning(sensorsCategory) << "Can't open config file" << config;
+            return;
+        }
 
         QTextStream stream(&cfgfile);
         QString line;
@@ -167,15 +168,21 @@ public Q_SLOTS:
 
 Q_GLOBAL_STATIC(QSensorManagerPrivate, sensorManagerPrivate)
 
-static void initPlugin(QObject *o)
+static void initPlugin(QObject *o, bool warnOnFail = true)
 {
-    if (!o) return;
+    qCDebug(sensorsCategory) << "Init plugin" << o;
+    if (!o) {
+        qCWarning(sensorsCategory) << "Null plugin" << o;
+        return;
+    }
 
     QSensorManagerPrivate *d = sensorManagerPrivate();
     if (!d) return; // hardly likely but just in case...
 
-    if (d->seenPlugins.contains(o))
+    if (d->seenPlugins.contains(o)) {
+        qCDebug(sensorsCategory) << "Plugin is seen" << o;
         return;
+    }
 
     QSensorChangesInterface *changes = qobject_cast<QSensorChangesInterface*>(o);
     if (changes)
@@ -184,8 +191,11 @@ static void initPlugin(QObject *o)
     QSensorPluginInterface *plugin = qobject_cast<QSensorPluginInterface*>(o);
 
     if (plugin) {
+        qCDebug(sensorsCategory) << "Register sensors for " << plugin;
         d->seenPlugins.insert(o);
         plugin->registerSensors();
+    } else if (warnOnFail) {
+        qCWarning(sensorsCategory) << "Can't cast to plugin" << o;
     }
 }
 
@@ -198,7 +208,7 @@ void QSensorManagerPrivate::loadPlugins()
     SENSORLOG() << "initializing static plugins";
     // Qt-style static plugins
     Q_FOREACH (QObject *plugin, QPluginLoader::staticInstances()) {
-        initPlugin(plugin);
+        initPlugin(plugin, false/*do not warn on fail*/);
     }
 
     if (d->loadExternalPlugins) {
